package net.jieyuu.controller;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import net.jieyuu.enums.BizCodeEnum;
import net.jieyuu.service.AddressService;
import net.jieyuu.service.FileService;
import net.jieyuu.utils.JsonData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author jieyuu
 * @since 2024-02-12
 */
@Api(tags = "用户模块")
@RestController
@RequestMapping("/api/user/v1/")
public class UserController {
    @Autowired
    AddressService addressService;
    @Autowired
    FileService fileService;

    @ApiOperation("根据id查询地址详情")
    @GetMapping("detail/{address_id}")
    public Object detail(
            @ApiParam(value = "地址", required = true)
            @PathVariable("address_id") long id) {
        return addressService.detail(id);
    }

    /**
     * 用户头像上传
     * 默认最大1M,超过报错
     *
     * @return
     */
    @ApiOperation("用户头像上传")
    @PostMapping(value = "upload")
    public JsonData uploadUserImg(
            @ApiParam(value = "文件上传", required = true)
            @RequestPart("file") MultipartFile file) throws IOException {
        String result = fileService.uploadUserHeadImg(file);

        return result!=null?JsonData.buildSuccess(result):JsonData.buildResult(BizCodeEnum.FILE_UPLOAD_USER_IMG_FAIL);
    }


}

